function trap_newton(f, fe, fy, a, b, alpha, N, TOL, M)
h       =   (b - a) / N;
T       =   zeros(1, N+1);  %   time
RK      =   zeros(1, N+1);  %   runge - kutta
TN      =   zeros(1, N+1);  %   trapezoidal - newton
EX      =   zeros(1, N+1);  %   exact
T       =   a : h : b;
RK(1)   =   alpha;
TN(1)   =   alpha;
EX(1)   =   alpha;

fprintf('\t\t\t\th = %.2f\t\t\t\t\th = %.2f\n', h, h);
fprintf('Ti\t\t\tWi\t\t\t|Yi - Wi|\t\tWi\t\t\t|Yi - Wi|\n');
disp('------------------------------------------------------------------------------------');

for i=1:N,
    f1      =   feval('f', T(i), RK(i));                        % Calculate RUNGE - KUTTA
    f2      =   feval('f', T(i) + h/2, RK(i) + h * f1 / 2);
    f3      =   feval('f', T(i) + h/2, RK(i) + h * f2 / 2);
    f4      =   feval('f', T(i) + h, RK(i) + h * f3);
    RK(i+1) =   RK(i) + h * (f1 + 2*f2 + 2*f3 + f4) / 6;
    
    EX(i+1) =   feval('fe', T(i+1));                            % Calculate EXACT Solution
    
    k1      =   TN(i) + h * feval('f', T(i), TN(i)) / 2;        % Calculate TRAPEZOIDAL Method
    w0      =   k1;
    
    for j=1:M,                                                  % Using NEWTON Method
        top     =   w0 - h * feval('f', T(i+1), w0) / 2 - k1;
        bottom  =   1 - h * feval('fy', T(i+1), w0) / 2;
        TN(i+1) =   w0 - top / bottom;
        if abs(TN(i+1) - w0) < TOL
            break;
        else
            w0 = TN(i+1);
            if j == M
                disp('The max number of iteration exceeded...');
            end;
        end;
    end;
end;

for i=1:N+1,
    if RK(i) > 10000
        fprintf('%.2f\t\t%.4E\t%.4E\t\t%f\t%.4E\n', T(i), RK(i), abs(RK(i) - EX(i)), TN(i), abs(TN(i) - EX(i)));
    else
        fprintf('%.2f\t\t%f\t%.4E\t\t%f\t%.4E\n', T(i), RK(i), abs(RK(i) - EX(i)), TN(i), abs(TN(i) - EX(i)));
    end;
end;
disp('------------------------------------------------------------------------------------');
